@@ -27,6 +27,10 @@ sub remove {
 	my $self = shift;
 	return $self->{session}->remove($self->{name});
 }
+sub spam {
+	my $self = shift;
+	return $self->{session}->spam($self->{name});
+}
 sub edit {
     	my ($self, $text) = @_;
 	croak 'This is not a self post' unless $self->{is_self};
@@ -54,6 +58,8 @@ sub unhide {
     $self->{session}->unhide($self->{name});
 }
 
+# The API return a 'permalink' that starts at '/r/sub..'
+# This just prepends the rest of the address
 sub get_permalink {
 	my $self = shift;
 	return "https://www.reddit.com$self->{permalink}";
